@@ -25,6 +25,11 @@ import warnings
 if sys.flags.interactive:
     plt.ion()
 
+# Workaround for matplotlib 1.1.1 not having a rc_context 
+if not hasattr(mpl, 'rc_context'):
+    from .utils import _rc_context
+    mpl.rc_context = _rc_context
+
 class ggplot(object):
     """
     ggplot is the base layer or object that you use to define
@@ -291,7 +296,12 @@ class ggplot(object):
             # Handling the details of the chart here; probably be a better
             # way to do this...
             if self.title:
-                plt.title(self.title)
+                if self.facets:
+                    # This is currently similar what plt.title uses
+                    plt.gcf().suptitle(self.title, verticalalignment='baseline',
+                                       fontsize=mpl.rcParams['axes.titlesize'])
+                else:
+                    plt.title(self.title)
             if self.xlab:
                 if self.facet_type == "grid":
                     fig.text(0.5, 0.025, self.xlab)
@@ -403,8 +413,8 @@ class ggplot(object):
     def add_to_legend(self, legend_type, legend_dict, scale_type="discrete"):
         """Adds the the specified legend to the legend
 
-        Parameter
-        ---------
+        Parameters
+        ----------
         legend_type : str
             type of legend, one of "color", "linestyle", "marker", "size"
         legend_dict : dict
