@@ -1,3 +1,5 @@
+from .scale_colour_brewer import scale_colour_brewer
+from .scale_colour_brewer import scale_colour_brewer as scale_color_brewer
 from .scale_colour_gradient import scale_colour_gradient
 from .scale_colour_gradient import scale_colour_gradient as scale_color_gradient
 from .scale_colour_gradient import scale_colour_gradient as scale_colour_gradient2
@@ -10,7 +12,8 @@ from .scale_y_continuous import scale_y_continuous
 from .scale_reverse import scale_y_reverse, scale_x_reverse
 from .scale_log import scale_y_log, scale_x_log
 
-__ALL__ = ['scale_color_gradient', 'scale_colour_gradient',
+__ALL__ = ['scale_color_brewer', 'scale_colour_brewer',
+           'scale_color_gradient', 'scale_colour_gradient',
            'scale_colour_gradient2', 'scale_colour_manual', 'scale_facet', 
            'scale_facet_grid', 'scale_facet_wrap', 'scale_reverse', 
            'scale_x_continuous', 'scale_x_date', 'scale_x_reverse', 
